"""Plotting utilities for atmospheric data visualization."""

from .core import (
    format_t_str,
    clean_legend,
    contour_legend,
    get_nth_color,
    get_next_color,
    get_cmap,
    add_row_header,
    shifted_colormap,
    plot_sounding,
    fig_multisave,
    sequential_cmap,
    single_color_cmap,
    transparent_under_cmap,
    share_axes,
    scale_axes_ticks,
    prepend_axes_letters,
    gif_from_pngs,
)

__all__ = [
    "format_t_str",
    "clean_legend",
    "contour_legend",
    "get_nth_color",
    "get_next_color",
    "get_cmap",
    "add_row_header",
    "shifted_colormap",
    "plot_sounding",
    "fig_multisave",
    "sequential_cmap",
    "single_color_cmap",
    "transparent_under_cmap",
    "share_axes",
    "scale_axes_ticks",
    "prepend_axes_letters",
    "gif_from_pngs",
]
